
import java.awt.*;
import java.io.*;
import java.sql.*;
import java.lang.*;

public class Connect 
{
    static Connection con;
    Statement stmt;
    ResultSet rs=null;
    
    public Connect() { }
       
    /**
     * connect with the specified database
     * @param url    url of the database to be connected
     * @param user   user of the database
     * @param passw  password of the user
     * @return       true, if connection was possible
     */
    public boolean getConnection(String url,String user, String passw)
    {
        try
		{
			Class.forName("sun.jdbc.odbc.JdbcOdbcDriver");
			con = DriverManager.getConnection(url,user,passw);		    
		    DatabaseMetaData dbmd = con.getMetaData();
		    System.out.println("Connected to " + dbmd.getURL());
		    System.out.println("Version " + dbmd.getDriverVersion());
		    System.out.println("DBMS: " + dbmd.getDatabaseProductName());
		    
		    return true;
		    //System.out.println("AutoCommit: " + con.getAutoCommit());
		    //rs=dbmd.getTables(null,"%","%",null); // Driver is not capable!
		}
		catch (java.sql.SQLException e)
		{
			System.err.println("Can't connect to database");
			System.err.println(e.getMessage());
			return false;
		}
		catch (ClassNotFoundException e)
		{
			System.err.println("Can't connect to database");
			System.err.println(e.getMessage());
			return false;
		}
    }
   /**
     * get dataspecific type for Longvarchar
     * @return type    dataspecific type
     */
    public String getType1()
    {
        String type="";
        try
        {  
            rs=con.getMetaData().getTypeInfo();
            while (rs.next())
            {
                 if (rs.getInt("DATA_TYPE") == Types.LONGVARCHAR)
                 {
                    type=rs.getString("TYPE_NAME");
                    rs.close();         
                    return type;
                 }
             }
            return type;
        }
        catch (java.sql.SQLException e)
		{
			System.err.println("Error: Can't get Datatype");
			System.err.println(e.getMessage());
		    return type;
		}
    }
    /**
      * get dataspecific type for Varchar
      * @return type    dataspecific type
      */
     public String getType2()
    {
        String type="";
        try
        {  
            rs=con.getMetaData().getTypeInfo();
            while (rs.next())
            {
                 if (rs.getInt("DATA_TYPE") == Types.VARCHAR)
                 {
                    type=rs.getString("TYPE_NAME");
                    rs.close();         
                    return type;
                 }
             }
            return type;
        }
        catch (java.sql.SQLException e)
		{
			System.err.println("Error: Can't get Datatype");
			System.err.println(e.getMessage());
		    return type;
		}
    }
    /**
      * close connection
      */
    public void closeConnection()
    {
        try
		{
			con.close();
		    System.out.println("Connection closed!");	 
		}
		catch (java.sql.SQLException e)
		{
			System.err.println("Can't close database");
			System.err.println(e.getMessage());
		}	
	}
	/**
      * accesses db
      * @param query    sql-String
      * @param update   true, if no resultSet is produced, otherwise false
      */
	public void dbAccess(String query,boolean update)
	{
	   
	   try
	   {
	        stmt=con.createStatement();
	        if (update) 
	        {
	            stmt.executeUpdate(query);
	            stmt.close();
	        }
	        else
	        {
	            rs=stmt.executeQuery(query);
	        }
	   }    
	   catch (java.sql.SQLException e) {
			 System.err.println(e.getMessage());
	   }
	} 
	/**
      * prepared access
      * @param pstmt    prepared statement
      * @param update   true, if no resultSet is produced, otherwise false
      */   
	public void preparedAccess(PreparedStatement pstmt, boolean update)
	{
	    try {
	        if (update)
	            pstmt.executeUpdate();
	        else
	        {
	            rs=pstmt.executeQuery();           
	        }
	    }
	    catch (java.sql.SQLException e){
	        System.err.println("error preparerrrr");
		    System.err.println(e.getMessage());
		    
		}
	} 
} 
